@@ -1,8 +1,8 @@
 # $File: //member/autrijus/Module-Signature/Signature.pm $ 
-# $Revision: #24 $ $Change: 1379 $ $DateTime: 2002/10/13 04:53:18 $
+# $Revision: #25 $ $Change: 1463 $ $DateTime: 2002/10/17 05:45:39 $
 
 package Module::Signature;
-$Module::Signature::VERSION = '0.13';
+$Module::Signature::VERSION = '0.14';
 
 use strict;
 use vars qw($VERSION $SIGNATURE @ISA @EXPORT_OK);
@@ -50,7 +50,7 @@ Module::Signature - Module signature file manipulation
 
 =head1 VERSION
 
-This document describes version 0.13 of B<Module::Signature>.
+This document describes version 0.14 of B<Module::Signature>.
 
 =head1 SYNOPSIS
 
@@ -238,7 +238,7 @@ sub _verify_gpg {
     my ($sigtext, $plaintext, $version) = @_;
 
     system(
-	'gpg', "--verify", ($KeyServer ? (
+	qw(gpg --verify --batch --no-tty), ($KeyServer ? (
 	    "--keyserver=$KeyServer",
 	    ($version ge "1.0.7")
 		? "--keyserver-options=auto-key-retrieve"
